#' Genetic correlation Z matrix for 62 traits
#'
#' Example genetic correlation Z matrix used in the vignette and examples.
#'
#' @format A numeric matrix.
#' @source Internal simulation
"Rg_mat_z"
